"use strict";
const fs = require("fs");
const path = require("path");
const cache_1 = require("./cache");
const concatFiles = (pkg) => (data, relPath) => `${data}${fs.readFileSync(path.join(pkg.path, relPath))}`;
module.exports = {
    getCacheKeyData(_, __, opts, pkg) {
        return (opts.cacheKeyFiles instanceof Array) ?
            opts.cacheKeyFiles.reduce(concatFiles(pkg), '') : '';
    },
    transpile(_, fileName, opts = {}) {
        const cache = cache_1.getCache(fileName);
        const moduleName = path.basename(fileName).replace(/\.[^.]*$/, '');
        const compilerOptions = Object.assign({}, cache.config.compilerOptions, opts);
        const output = {};
        try {
            const ts = cache.transpiler;
            const fileSrc = fs.readFileSync(fileName, 'utf8');
            if (ts !== undefined) {
                const result = ts.transpileModule(fileSrc, { compilerOptions, fileName, moduleName });
                output.code = result.outputText;
            }
            else {
                output.code = fileSrc;
            }
        }
        catch (err) {
            console.error(`Encountered an error while attempting to transpile module '${moduleName}' from path ${fileName}:\n\n${err.message}`);
        }
        return output;
    },
};
