"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
function* searchLocations(baseDir, resource) {
    let next = baseDir;
    let prev = '';
    while (prev !== next && path.basename(next) !== 'node_modules') {
        yield `${next}/${resource}`;
        prev = next;
        next = path.join(next, '../');
    }
}
function resolveResource(baseDir, fileName) {
    for (const location of searchLocations(baseDir, fileName)) {
        if (fs.existsSync(location)) {
            return location;
        }
    }
    return undefined;
}
function parseTsConfig(location) {
    try {
        const data = fs.readFileSync(location);
        return JSON.parse(data.toString());
    }
    catch (err) {
        console.error(`Failed to parse tsconfig located at ${location}.
    Is your configuration file properly formatted JSON?. Error message was:
    \n${err.message}`);
        return {};
    }
}
function resolveConfig(baseDir) {
    const location = resolveResource(baseDir, 'tsconfig.json');
    if (location !== undefined) {
        return parseTsConfig(location);
    }
    else {
        return {};
    }
}
exports.resolveConfig = resolveConfig;
function resolveTranspiler(baseDir) {
    const location = resolveResource(baseDir, 'node_modules');
    try {
        const transpiler = require(`${location}/typescript`);
        return transpiler;
    }
    catch (err) {
        console.error(`Failed to load transpiler for directory ${baseDir}.\n
Do you have TypeScript installed as a peerDependency? Error message was:
\n${err.message}`);
        return undefined;
    }
}
exports.resolveTranspiler = resolveTranspiler;
